==> mastapy-13.0.0.post4-py3-none-any.whl: mastapy/gears/gear_designs/cylindrical/micro_geometry/_1131.py <==
"""TotalProfileReliefWithDeviation"""

from __future__ import annotations

from typing import TYPE_CHECKING, TypeVar

from mastapy.gears.gear_designs.cylindrical.micro_geometry import _1126
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_TOTAL_PROFILE_RELIEF_WITH_DEVIATION = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical.MicroGeometry",
    "TotalProfileReliefWithDeviation",
)

if TYPE_CHECKING:
    from mastapy.gears.gear_designs.cylindrical.micro_geometry import _1128


__docformat__ = "restructuredtext en"
__all__ = ("TotalProfileReliefWithDeviation",)


Self = TypeVar("Self", bound="TotalProfileReliefWithDeviation")


class TotalProfileReliefWithDeviation(_1126.ProfileReliefWithDeviation):
    """TotalProfileReliefWithDeviation

    This is a mastapy class.
    """

    TYPE = _TOTAL_PROFILE_RELIEF_WITH_DEVIATION
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_TotalProfileReliefWithDeviation")

    class _Cast_TotalProfileReliefWithDeviation:
        """Special nested class for casting TotalProfileReliefWithDeviation to subclasses."""

        def __init__(
            self: "TotalProfileReliefWithDeviation._Cast_TotalProfileReliefWithDeviation",
            parent: "TotalProfileReliefWithDeviation",
        ):
            self._parent = parent

        @property
        def profile_relief_with_deviation(
            self: "TotalProfileReliefWithDeviation._Cast_TotalProfileReliefWithDeviation",
        ) -> "_1126.ProfileReliefWithDeviation":
            return self._parent._cast(_1126.ProfileReliefWithDeviation)

        @property
        def relief_with_deviation(
            self: "TotalProfileReliefWithDeviation._Cast_TotalProfileReliefWithDeviation",
        ) -> "_1128.ReliefWithDeviation":
            from mastapy.gears.gear_designs.cylindrical.micro_geometry import _1128

            return self._parent._cast(_1128.ReliefWithDeviation)

        @property
        def total_profile_relief_with_deviation(
            self: "TotalProfileReliefWithDeviation._Cast_TotalProfileReliefWithDeviation",
        ) -> "TotalProfileReliefWithDeviation":
            return self._parent

        def __getattr__(
            self: "TotalProfileReliefWithDeviation._Cast_TotalProfileReliefWithDeviation",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "TotalProfileReliefWithDeviation.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cast_to(
        self: Self,
    ) -> "TotalProfileReliefWithDeviation._Cast_TotalProfileReliefWithDeviation":
        return self._Cast_TotalProfileReliefWithDeviation(self)

==> mastapy-13.0.1.post3-py3-none-any.whl: mastapy/gears/gear_designs/cylindrical/micro_geometry/_1131.py <==
"""TotalProfileReliefWithDeviation"""

from __future__ import annotations

from typing import TypeVar

from mastapy.gears.gear_designs.cylindrical.micro_geometry import _1126
from mastapy._internal.cast_exception import CastException
from mastapy._internal.python_net import python_net_import

_TOTAL_PROFILE_RELIEF_WITH_DEVIATION = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical.MicroGeometry",
    "TotalProfileReliefWithDeviation",
)


__docformat__ = "restructuredtext en"
__all__ = ("TotalProfileReliefWithDeviation",)


Self = TypeVar("Self", bound="TotalProfileReliefWithDeviation")


class TotalProfileReliefWithDeviation(_1126.ProfileReliefWithDeviation):
    """TotalProfileReliefWithDeviation

    This is a mastapy class.
    """

    TYPE = _TOTAL_PROFILE_RELIEF_WITH_DEVIATION
    _CastSelf = TypeVar("_CastSelf", bound="_Cast_TotalProfileReliefWithDeviation")

    class _Cast_TotalProfileReliefWithDeviation:
        """Special nested class for casting TotalProfileReliefWithDeviation to subclasses."""

        def __init__(
            self: "TotalProfileReliefWithDeviation._Cast_TotalProfileReliefWithDeviation",
            parent: "TotalProfileReliefWithDeviation",
        ):
            self._parent = parent

        @property
        def profile_relief_with_deviation(
            self: "TotalProfileReliefWithDeviation._Cast_TotalProfileReliefWithDeviation",
        ):
            return self._parent._cast(_1126.ProfileReliefWithDeviation)

        @property
        def relief_with_deviation(
            self: "TotalProfileReliefWithDeviation._Cast_TotalProfileReliefWithDeviation",
        ):
            from mastapy.gears.gear_designs.cylindrical.micro_geometry import _1128

            return self._parent._cast(_1128.ReliefWithDeviation)

        @property
        def total_profile_relief_with_deviation(
            self: "TotalProfileReliefWithDeviation._Cast_TotalProfileReliefWithDeviation",
        ) -> "TotalProfileReliefWithDeviation":
            return self._parent

        def __getattr__(
            self: "TotalProfileReliefWithDeviation._Cast_TotalProfileReliefWithDeviation",
            name: str,
        ):
            try:
                return self.__dict__[name]
            except KeyError:
                class_name = "".join(n.capitalize() for n in name.split("_"))
                raise CastException(
                    f'Detected an invalid cast. Cannot cast to type "{class_name}"'
                ) from None

    def __init__(self: Self, instance_to_wrap: "TotalProfileReliefWithDeviation.TYPE"):
        super().__init__(instance_to_wrap)
        self._freeze()

    @property
    def cast_to(
        self: Self,
    ) -> "TotalProfileReliefWithDeviation._Cast_TotalProfileReliefWithDeviation":
        return self._Cast_TotalProfileReliefWithDeviation(self)
